[Commits] [SCM] claws branch, gtk2, updated. 3.20.0-91-g4636eae6c

paul at claws-mail.org paul at claws-mail.org
Thu May 16 17:21:51 UTC 2024


The branch, gtk2 has been updated
       via  4636eae6c488b341b0078985116ec1d780f4e771 (commit)
      from  e7606c3a88bed6b9979828046612f09d43210c8a (commit)

Summary of changes:
 src/common/hooks.c | 6 +++---
 src/common/hooks.h | 8 ++++----
 2 files changed, 7 insertions(+), 7 deletions(-)


- Log -----------------------------------------------------------------
commit 4636eae6c488b341b0078985116ec1d780f4e771
Author: Paul <paul at claws-mail.org>
Date:   Thu May 16 18:19:56 2024 +0100

    finally, use the proper name for the hooks

diff --git a/src/common/hooks.c b/src/common/hooks.c
index 230fb7130..33172c9c6 100644
--- a/src/common/hooks.c
+++ b/src/common/hooks.c
@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2024 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ static GHookList *hooks_get_hooklist(const gchar *hooklist_name)
 }
 
 gulong hooks_register_hook(const gchar *hooklist_name,
-			  SylpheedHookFunction hook_func,
+			  ClawsMailHookFunction hook_func,
 			  gpointer userdata)
 {
 	GHookList *hooklist;
diff --git a/src/common/hooks.h b/src/common/hooks.h
index bbb4d3e34..3309d5c97 100644
--- a/src/common/hooks.h
+++ b/src/common/hooks.h
@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 
 #define HOOK_NONE 0
 
-typedef gboolean (*SylpheedHookFunction)	(gpointer source,
+typedef gboolean (*ClawsMailHookFunction)	(gpointer source,
 						 gpointer userdata);
 
 gulong hooks_register_hook	(const gchar		*hooklist_name,
-				 SylpheedHookFunction	 hook_func,
+				 ClawsMailHookFunction	 hook_func,
 				 gpointer		 userdata);
 void hooks_unregister_hook	(const gchar		*hooklist_name,
 				 gulong			 hook_id);

-----------------------------------------------------------------------
@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2024 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify


hooks/post-receive
-- 
Claws Mail


More information about the Commits mailing list